# rasterbox
[Project on PyPi](https://pypi.org/project/rasterbox/)

Data holder and manipulator for raster images
The purpose of rasterbox is to allow seemless storage, and retrieval of raw raster data and target labels associated with the data. This is a hyper-specific use-case, and likely doesn't warrant a package, yet here we are.
## Installation - TODO
## Usage
To create a rasterbox object, you need only supply the path to your binary raster files, the path to the associated targets, and a list of available targets.


